@@ -1,17 +1,17 @@
 import numpy as np
-from surpyval import nonparametric as nonp
 from scipy.stats import t, norm
-from .kaplan_meier import KaplanMeier
-from .nelson_aalen import NelsonAalen
-from .fleming_harrington import FlemingHarrington_
-
 from scipy.interpolate import interp1d
-from autograd import jacobian
 
 import matplotlib.pyplot as plt
 import pandas as pd
 
 
+def interp_function(x, y, kind):
+    return interp1d(x, y, kind=kind,
+                    bounds_error=False,
+                    fill_value=np.nan)
+
+
 class NonParametric():
     """
     Result of ``.fit()`` method for every non-parametric
@@ -26,9 +26,10 @@ class NonParametric():
                + '\nModel            : {dist}'
                ).format(dist=self.model)
 
-        if 'estimator' in self.data:
-            out += '\nEstimator        : {turnbull}'.format(
-                turnbull=self.data['estimator'])
+        if hasattr(self, 'data'):
+            if 'estimator' in self.data:
+                out += '\nEstimator        : {turnbull}'.format(
+                    turnbull=self.data['estimator'])
 
         return out
 
@@ -72,12 +73,14 @@ class NonParametric():
             R = np.where(idx < 0, 1, R)
             R = np.where(np.isposinf(x), 0, R)
         else:
-            R = np.hstack([[1], self.R])
-            x_data = np.hstack([[0], self.x])
-            # R = np.interp(x, x_data, R)
-            R = interp1d(x_data, R, kind=interp)(x)
-            R[np.where(x > self.x.max())] = np.nan
-        return R[rev]
+            R = interp_function(self.x, self.R, kind=interp)(x)
+
+        R = R[rev]
+        # Maybe set a parameter where 'extrapolate' is False
+        # x = x[rev]
+        # R = np.where(x < self.x.min(), np.nan, R)
+        # R = np.where(x > self.x.max(), np.nan, R)
+        return R
 
     def ff(self, x, interp='step'):
         r"""
@@ -292,6 +295,12 @@ class NonParametric():
 
         old_err_state = np.seterr(all='ignore')
 
+        # Reverse for ff and F
+        if on in ['ff', 'F', 'Hf', 'hf', 'df'] and bound == 'lower':
+            bound = 'upper'
+        elif on in ['ff', 'F', 'Hf', 'hf', 'df'] and bound == 'upper':
+            bound = 'lower'
+
         cb = self.R_cb(x,
                        bound=bound,
                        interp=interp,
@@ -339,13 +348,27 @@ class NonParametric():
 
         if bound_type == 'exp':
             # Exponential Greenwood confidence
+            # print(self.greenwood)
             R_out = self.greenwood * 1. / (np.log(self.R)**2)
             R_out = np.log(-np.log(self.R)) - stat * np.sqrt(R_out)
             R_out = np.exp(-np.exp(R_out))
+            R_out = np.where(self.greenwood == 0, 1, R_out)
         else:
             # Normal Greenwood confidence
             R_out = self.R + np.sqrt(self.greenwood * self.R**2) * stat
 
+        # Allows for confidence bound to be estimated up to the last value.
+        # only used in event that there is no right censoring.
+        if bound == 'upper':
+            R_out = np.where(np.isfinite(R_out), R_out, np.nanmin(R_out))
+        elif bound == 'lower':
+            R_out = np.where(np.isfinite(R_out), R_out, 0)
+        else:
+            R_out[0, :] = np.where(np.isfinite(R_out[0, :]),
+                                   R_out[0, :],
+                                   np.nanmin(R_out[0, :]))
+            R_out[1, :] = np.where(np.isfinite(R_out[1, :]), R_out[1, :], 0)
+
         if interp == 'step':
             idx = np.searchsorted(self.x, x, side='right') - 1
             if bound == 'two-sided':
@@ -357,29 +380,19 @@ class NonParametric():
 
         else:
             if bound == 'two-sided':
-                R1 = interp1d(self.x, R_out[0, :], kind=interp)(x)
-                R2 = interp1d(self.x, R_out[1, :], kind=interp)(x)
+                R1 = interp_function(self.x, R_out[0, :], kind=interp)(x)
+                R2 = interp_function(self.x, R_out[1, :], kind=interp)(x)
                 R_out = np.vstack([R1, R2])
             else:
-                R_out = interp1d(self.x, R_out, kind=interp)(x)
+                R_out = interp_function(self.x, R_out, kind=interp)(x)
 
-        if R_out.ndim == 2:
-            min_idx = (x < self.x.min())
-            max_idx = (x > self.x.max())
-            # print(R_out[0, :])
-            R_out[0, :][min_idx] = 1
-            R_out[0, :][max_idx] = 1
-            R_out[1, :][min_idx] = 0
-            R_out[1, :][max_idx] = 0
+        # The question remains. Should bounds above and below observed values
+        # be calculable?...
+        mask = (x < self.x.min()) | (x > self.x.max())
+        R_out = np.where(mask, np.nan, R_out)
+
+        if bound == 'two-sided':
             R_out = R_out.T
-            # print(R_out)
-            # nan_idx = ((x < self.x.min()) | (x > self.x.max()))
-            # R_out[nan_i3dx] = np.nan
-        else:
-            min_idx = (x < self.x.min())
-            max_idx = (x > self.x.max())
-            R_out[min_idx] = 0
-            R_out[max_idx] = 1
 
         np.seterr(**old_err_state)
 
@@ -447,5 +460,5 @@ class NonParametric():
             ax.step(d['x_'], d['R'], where='post')
             if plot_bounds:
                 ax.step(d['x_'], d['cbs'], color='r', where='post')
-        
+
         return ax
